import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl =
  'https://gist.githubusercontent.com/SirishaManthena/3449ab5a358b86c1f77ebc2a79b78d89/raw/30d91ca1189670be09f56d0011f9839517e24034/menu_items.csv';
const parseRow = (d) => {
  d.protein = +d.protein;
  d.carbohydrates = +d.carbohydrates;
  d.total_fat = +d.total_fat;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.carbohydrates)
    .yValue((d) => d.protein)
    .margin({
      top: 50,
      right: 50,
      bottom: 80,
      left: 80,
    }) // Increased margins for titles
    .radius(5);

  svg.call(plot);

  const columns = ['carbohydrates', 'total_fat', 'protein'];
  const titles = [
    'Carbohydrates vs Protein',
    'Carbohydrates vs Total Fat',
    'Protein vs Total Fat',
  ];
  let i = 0;

  // Append title element to the SVG
  svg
    .append('text')
    .attr('class', 'title')
    .attr('x', width / 2)
    .attr('y', 30)
    .attr('text-anchor', 'middle')
    .attr('font-size', '18px')
    .text(titles[i]);

  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    plot.yValue(
      (d) => d[columns[(i + 1) % columns.length]],
    ); // Update y-axis value
    svg.call(plot);
    svg.select('.title').text(titles[i % titles.length]); // Update title
    i++;
  }, 2000);
};
main();
